@@ -1,4 +1,5 @@
-use serde::{Deserialize, Serialize};
+use serde::Deserialize;
+use serde::Serialize;
 use std::collections::HashMap;
 
 #[derive(Debug, Clone, PartialEq, Eq)]
@@ -68,6 +69,12 @@ pub struct ConfigurationDiagnostic {
   pub message: String,
 }
 
+impl std::fmt::Display for ConfigurationDiagnostic {
+  fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+    write!(f, "{} ({})", self.message, self.property_name)
+  }
+}
+
 pub type ConfigKeyMap = HashMap<String, ConfigKeyValue>;
 
 /// Creates a ConfigKeyMap from a series of string key value pairs.
@@ -99,6 +106,7 @@ impl ConfigKeyValue {
     ConfigKeyValue::Number(value)
   }
 
+  #[allow(clippy::should_implement_trait)]
   pub fn from_str(value: &str) -> ConfigKeyValue {
     ConfigKeyValue::String(value.to_string())
   }
@@ -233,8 +241,8 @@ where
       Ok(parsed_value) => Some(parsed_value),
       Err(message) => {
         diagnostics.push(ConfigurationDiagnostic {
-          property_name: String::from(key),
-          message: format!("Error parsing configuration value for '{}'. Message: {}", key, message),
+          property_name: key.to_string(),
+          message: message.to_string(),
         });
         None
       }
@@ -252,8 +260,8 @@ pub fn handle_renamed_config_property(config: &mut ConfigKeyMap, old_key: &'stat
       config.insert(new_key.to_string(), raw_value);
     }
     diagnostics.push(ConfigurationDiagnostic {
-      property_name: String::from(old_key),
-      message: format!("The configuration key '{}' was renamed to '{}'.", old_key, new_key),
+      property_name: old_key.to_string(),
+      message: format!("The configuration key was renamed to '{}'.", new_key),
     });
   }
 }
@@ -298,8 +306,8 @@ pub fn get_unknown_property_diagnostics(config: ConfigKeyMap) -> Vec<Configurati
   let mut diagnostics = Vec::new();
   for (key, _) in config.iter() {
     diagnostics.push(ConfigurationDiagnostic {
-      property_name: String::from(key),
-      message: format!("Unknown property in configuration: {}", key),
+      property_name: key.to_string(),
+      message: "Unknown property in configuration.".to_string(),
     });
   }
   diagnostics
@@ -323,11 +331,12 @@ mod test {
 
   #[test]
   fn get_values_when_filled() {
-    let mut global_config = HashMap::new();
-    global_config.insert(String::from("lineWidth"), ConfigKeyValue::from_i32(80));
-    global_config.insert(String::from("indentWidth"), ConfigKeyValue::from_i32(8));
-    global_config.insert(String::from("newLineKind"), ConfigKeyValue::from_str("crlf"));
-    global_config.insert(String::from("useTabs"), ConfigKeyValue::from_bool(true));
+    let global_config = HashMap::from([
+      (String::from("lineWidth"), ConfigKeyValue::from_i32(80)),
+      (String::from("indentWidth"), ConfigKeyValue::from_i32(8)),
+      (String::from("newLineKind"), ConfigKeyValue::from_str("crlf")),
+      (String::from("useTabs"), ConfigKeyValue::from_bool(true)),
+    ]);
     let config_result = resolve_global_config(global_config, &Default::default());
     let config = config_result.config;
     assert_eq!(config_result.diagnostics.len(), 0);
@@ -339,44 +348,34 @@ mod test {
 
   #[test]
   fn get_diagnostic_for_invalid_enum_config() {
-    let mut global_config = HashMap::new();
-    global_config.insert(String::from("newLineKind"), ConfigKeyValue::from_str("something"));
+    let global_config = HashMap::from([(String::from("newLineKind"), ConfigKeyValue::from_str("something"))]);
     let diagnostics = resolve_global_config(global_config, &Default::default()).diagnostics;
     assert_eq!(diagnostics.len(), 1);
-    assert_eq!(
-      diagnostics[0].message,
-      "Error parsing configuration value for 'newLineKind'. Message: Found invalid value 'something'."
-    );
+    assert_eq!(diagnostics[0].message, "Found invalid value 'something'.");
     assert_eq!(diagnostics[0].property_name, "newLineKind");
   }
 
   #[test]
   fn get_diagnostic_for_invalid_primitive() {
-    let mut global_config = HashMap::new();
-    global_config.insert(String::from("useTabs"), ConfigKeyValue::from_str("something"));
+    let global_config = HashMap::from([(String::from("useTabs"), ConfigKeyValue::from_str("something"))]);
     let diagnostics = resolve_global_config(global_config, &Default::default()).diagnostics;
     assert_eq!(diagnostics.len(), 1);
-    assert_eq!(
-      diagnostics[0].message,
-      "Error parsing configuration value for 'useTabs'. Message: provided string was not `true` or `false`"
-    );
+    assert_eq!(diagnostics[0].message, "provided string was not `true` or `false`");
     assert_eq!(diagnostics[0].property_name, "useTabs");
   }
 
   #[test]
   fn get_diagnostic_for_excess_property() {
-    let mut global_config = HashMap::new();
-    global_config.insert(String::from("something"), ConfigKeyValue::from_str("value"));
+    let global_config = HashMap::from([(String::from("something"), ConfigKeyValue::from_str("value"))]);
     let diagnostics = resolve_global_config(global_config, &Default::default()).diagnostics;
     assert_eq!(diagnostics.len(), 1);
-    assert_eq!(diagnostics[0].message, "Unknown property in configuration: something");
+    assert_eq!(diagnostics[0].message, "Unknown property in configuration.");
     assert_eq!(diagnostics[0].property_name, "something");
   }
 
   #[test]
   fn no_diagnostic_for_excess_property_when_check_false() {
-    let mut global_config = HashMap::new();
-    global_config.insert(String::from("something"), ConfigKeyValue::from_str("value"));
+    let global_config = HashMap::from([(String::from("something"), ConfigKeyValue::from_str("value"))]);
     let diagnostics = resolve_global_config(
       global_config,
       &ResolveGlobalConfigOptions {
@@ -396,7 +395,8 @@ mod test {
     assert_eq!(config.len(), 1);
     assert_eq!(config.remove("newProp").unwrap(), ConfigKeyValue::from_str("value"));
     assert_eq!(diagnostics.len(), 1);
-    assert_eq!(diagnostics[0].message, "The configuration key 'oldProp' was renamed to 'newProp'.");
+    assert_eq!(diagnostics[0].message, "The configuration key was renamed to 'newProp'.");
+    assert_eq!(diagnostics[0].property_name, "oldProp");
   }
 
   #[test]
@@ -409,6 +409,7 @@ mod test {
     assert_eq!(config.len(), 1);
     assert_eq!(config.remove("newProp").unwrap(), ConfigKeyValue::from_str("value"));
     assert_eq!(diagnostics.len(), 1);
-    assert_eq!(diagnostics[0].message, "The configuration key 'oldProp' was renamed to 'newProp'.");
+    assert_eq!(diagnostics[0].message, "The configuration key was renamed to 'newProp'.");
+    assert_eq!(diagnostics[0].property_name, "oldProp");
   }
 }
