@@ -1,6 +1,3 @@
-#[macro_use]
-pub mod types;
-
 #[cfg(feature = "formatting")]
 pub mod formatting;
 
